powered by
Feature Importance methods
fi_ranger_rf_lite( num_trees = 2000, num_variables_per_split = 50, num_samples_per_tree = 250, min_node_size = 20, ... )fi_ranger_rf(...)fi_caret(caret_method, ...)fi_ranger_rf_tiny( num_trees = 100, num_variables_per_split = 50, num_samples_per_tree = 250, min_node_size = 20, ... )
fi_ranger_rf(...)
fi_caret(caret_method, ...)
fi_ranger_rf_tiny( num_trees = 100, num_variables_per_split = 50, num_samples_per_tree = 250, min_node_size = 20, ... )
A list containing a helper function for calling a feature importance function.
(fi_ranger_rf_lite) The number of trees to use
(fi_ranger_rf_lite) The number of variables to sample per split
(fi_ranger_rf_lite) The number of samples to bootstrap per split
(fi_ranger_rf_lite) The minimum node size, no split will be made if the node size is less than this value.
Extra parameters to pass onto the underlying feature importance function.
(fi_caret) Which caret method to use for feature importance.
library(dynwrap) data(example_trajectory) calculate_overall_feature_importance(example_trajectory, fi_method = fi_ranger_rf())
Run the code above in your browser using DataLab